@@ -4,6 +4,7 @@
 #!/usr/bin/env python
 # coding: utf-8
 import numpy as np
+import time
 from statsmodels.stats.power import NormalIndPower
 
 #提升多少ipr
@@ -13,12 +14,12 @@ def ipr(old_num,new_num):
 
 #AB样本量计算ABSample
 def ABSample():
-    print("请输入实验主要指标当前值 _？？_ %（比如点击率，留存率等，一般都是率或者占比）")
+    print("请输入实验主要指标当前值 __ %（点击率，留存率等，比如：35%请直接输入 35）")
     u=input()
     u=float(u)/100
-    print("请输入最小可以观测的提升比例_？_% （就是最少提升多少你觉得才ok，相对值,取绝对值）")
+    print("请输入最小可以观测的提升比例__% （就是最少提升百分之几你觉得才ok，相对提升的量）")
     r=input()
-    r=float(r)/100
+    r=abs(float(r)/100)
     zpower = NormalIndPower()
     effect_size =u*r/np.sqrt(u*(1-u))
     res=(zpower.solve_power(
@@ -29,6 +30,8 @@ def ABSample():
        ratio=1.0,
        alternative='two-sided'
             ))
+    print("计算中……,计算结果如下")
+    time.sleep(3)
     print('******* 您的AB实验，实验组需要的用户量为：{0}人 ******'.format(int(res)))
                    
     
\ No newline at end of file
